@@ -2,8 +2,8 @@
 
 ;; Author: Lassi Kortela <lassi@lassi.io>
 ;; URL: https://github.com/lassik/emacs-format-all-the-code
-;; Package-Version: 0.6.0
-;; Package-Revision: 1f4a69811b4b
+;; Package-Version: 20241126.829
+;; Package-Revision: fd9c013f5f80
 ;; Package-Requires: ((emacs "24.4") (inheritenv "0.1") (language-id "0.20"))
 ;; Keywords: languages util
 ;; SPDX-License-Identifier: MIT
@@ -27,6 +27,7 @@
 ;; - Assembly (asmfmt)
 ;; - ATS (atsfmt)
 ;; - Awk (gawk)
+;; - AZSL (clang-format)
 ;; - Bazel Starlark (buildifier)
 ;; - Beancount (bean-format)
 ;; - BibTeX (Emacs)
@@ -34,7 +35,7 @@
 ;; - C# (clang-format, astyle, csharpier)
 ;; - Cabal (cabal-fmt)
 ;; - Caddyfile (caddy fmt)
-;; - Clojure/ClojureScript (zprint, node-cljfmt)
+;; - Clojure/ClojureScript (cljfmt, zprint)
 ;; - CMake (cmake-format)
 ;; - Crystal (crystal tool format)
 ;; - CSS/Less/SCSS (prettier, prettierd)
@@ -57,9 +58,10 @@
 ;; - GraphQL (prettier, prettierd)
 ;; - Haskell (brittany, fourmolu, hindent, ormolu, stylish-haskell)
 ;; - HCL (hclfmt)
+;; - HLSL (clang-format)
 ;; - HTML/XHTML/XML (tidy)
 ;; - Hy (Emacs)
-;; - Java (clang-format, astyle)
+;; - Java (astyle, clang-format, google-java-format)
 ;; - JavaScript/JSON/JSX (prettier, standard, prettierd, deno)
 ;; - Jsonnet (jsonnetfmt)
 ;; - Kotlin (ktlint)
@@ -156,11 +158,12 @@
     ("GraphQL" prettier)
     ("Haskell" brittany)
     ("HCL" hclfmt)
+    ("HLSL" clang-format)
     ("HTML" html-tidy)
     ("HTML+EEX" mix-format)
     ("HTML+ERB" erb-format)
     ("Hy" emacs-hy)
-    ("Java" clang-format)
+    ("Java" google-java-format)
     ("JavaScript" prettier)
     ("JSON" prettier)
     ("JSON5" prettier)
@@ -205,6 +208,7 @@
     ("Zig" zig)
 
     ("_Angular" prettier)
+    ("_AZSL" clang-format)
     ("_Beancount" bean-format)
     ("_Caddyfile" caddy-fmt)
     ("_Flow" prettier)
@@ -740,13 +744,21 @@ Consult the existing formatters for examples of BODY."
   (:features)
   (:format (format-all--buffer-easy executable "fmt" "-")))
 
+(define-format-all-formatter cargo-fmt
+  ;; This is the same formatter as rustfmt, but run via `cargo fmt`.
+  (:executable "cargo")
+  (:install "rustup component add rustfmt")
+  (:languages "Rust")
+  (:features)
+  (:format (format-all--buffer-easy executable "fmt")))
+
 (define-format-all-formatter clang-format
   (:executable "clang-format")
   (:install
    (macos "brew install clang-format")
    (windows "scoop install llvm"))
   (:languages
-   "C" "C#" "C++" "Cuda" "GLSL" "Java" "Objective-C" "Protocol Buffer")
+   "_AZSL" "C" "C#" "C++" "Cuda" "GLSL" "HLSL" "Java" "Objective-C" "Protocol Buffer")
   (:features region)
   (:format
    (format-all--buffer-easy
@@ -768,10 +780,10 @@ Consult the existing formatters for examples of BODY."
 
 (define-format-all-formatter cljfmt
   (:executable "cljfmt")
-  (:install "npm install --global node-cljfmt")
+  (:install)
   (:languages "Clojure")
   (:features)
-  (:format (format-all--buffer-easy executable)))
+  (:format (format-all--buffer-easy executable "fix" "-")))
 
 (define-format-all-formatter cmake-format
   (:executable "cmake-format")
@@ -982,6 +994,13 @@ Consult the existing formatters for examples of BODY."
   (:features)
   (:format (format-all--buffer-easy executable)))
 
+(define-format-all-formatter google-java-format
+  (:executable "google-java-format")
+  (:install)
+  (:languages "Java")
+  (:features)
+  (:format (format-all--buffer-easy executable "-")))
+
 (define-format-all-formatter hclfmt
   (:executable "hclfmt")
   (:install "go install github.com/hashicorp/hcl/v2/cmd/hclfmt@latest")
@@ -1512,6 +1531,7 @@ unofficial languages IDs are prefixed with \"_\"."
            (boundp 'flow-minor-mode)
            (not (null (symbol-value 'flow-minor-mode)))
            "_Flow")
+      (and (equal major-mode 'azsl-mode) "_AZSL")
       (and (equal major-mode 'beancount-mode) "_Beancount")
       (and (equal major-mode 'caddyfile-mode) "_Caddyfile")
       (and (equal major-mode 'gleam-mode) "_Gleam")
